@@ -18,7 +18,7 @@ use Sub::Exporter -setup =>
 	};
 	
 use vars qw ($VERSION);
-$VERSION     = '0.07';
+$VERSION     = '0.09';
 }
 
 #-------------------------------------------------------------------------------
@@ -52,7 +52,8 @@ Data::HexDump::Range - Hexadecial Range Dumper
 
   my $hdr = Data::HexDump::Range->new() ;
   
-  print $hdr->dump(['magic cookie', 12, 'red'], $data) ;
+  print $hdr->dump([['magic cookie', 12, 'red'],['image type', 2, 'green']],  $data) ;
+  print $hdr->dump('magic cookie, 12, red :image type, 2, green',  $data) ;
   
   $hdr->gather(['magic cookie', 12, 'red'], $data) ; 
   $hdr->gather(['image type', 2, 'green'], $other_data) ;
@@ -62,8 +63,10 @@ Data::HexDump::Range - Hexadecial Range Dumper
 
 =head1 DESCRIPTION
 
-Creates a dump from binary data and user defined I<range> descriptions. The goal of this modules is
-to create an easy to understand dump of binary data. This achieved through:
+Creates a dump from binary data and user defined I<range> descriptions. The goal of this module is
+to create an easy to understand dump of binary data. 
+
+This achieved through:
 
 =over 2
 
@@ -73,6 +76,8 @@ to create an easy to understand dump of binary data. This achieved through:
 
 =item * Bitfield rendering
 
+=item * Skipping uninterresting data
+
 =item * The possibility to describe complex structures
 
 =back
@@ -80,10 +85,10 @@ to create an easy to understand dump of binary data. This achieved through:
 =head1 DOCUMENTATION
 
 The shortest perl dumper is C<perl -ne 'BEGIN{$/=\16} printf "%07x0: @{[unpack q{(H2)*}]}\n", $.-1'>, courtesy of a golfing session 
-with Andrew Rodland <arodland@cpan.org> aka I<hobbs>. I<priodev>, I<tm604>, I<Khisanth> and other helped with the html output.
+with Andrew Rodland <arodland@cpan.org> aka I<hobbs>. I<priodev>, I<tm604>, I<Khisanth> and other provided valuable insight particularely  with the html output.
 
-B<hexd> from libma L<http://www.ioplex.com/~miallen/libmba/> is nice tools that inspired me to write this module. It may be a better 
-alternative If you need very fast dump generation.
+B<hexd> from libma L<http://www.ioplex.com/~miallen/libmba/> is nice tools that inspired me to write this module. This module offers many
+more options but B<hexd> may be a better  alternative If you need very fast dump generation.
 
 B<Data::HexDump::Range> splits binary data according to user defined I<ranges> and rendered as a B<hex> or/and B<decimal> data dump.
 The data dump can be rendered in ANSI, ASCII or HTML.
@@ -91,7 +96,11 @@ The data dump can be rendered in ANSI, ASCII or HTML.
 =head2 Rendered Columns
 
 You can choose which columns are rendered by setting options when creating a Data::HexDump::Range object.
-The default rendering corresponds to the object below:
+The default rendering  includes the following
+
+  RANGE_NAME OFFSET CUMULATIVE_OFFSET HEX_DUMP ASCII_DUMP
+
+which corresponds to the object below:
 
   Data::HexDump::Range->new
 	(
@@ -111,14 +120,16 @@ The default rendering corresponds to the object below:
 	DATA_WIDTH => 16,
 	) ;
 
-If you decided that you wanted the binary data to be showed in decimal instead for hexadecimal, you' set B<<DISPLAY_HEX_DUMP => 0>> and B<<DISPLAY_DEC_DUMP => 1>>.
+If you decided that you wanted the binary data to be showed in decimal instead for hexadecimal, you' set DISPLAY_HEX_DUMP => 0 and DISPLAY_DEC_DUMP => 1.
 See L<new> for all the possible options. Most option are also available from the command line utility I<hdr>.
 
 =head2 Orientation
 
-Command: I<hdr -r 'magic cookie,12:padding, 32:header,5:data, 20:extra data,#:header,5:data,40:footer,4' -col -o ver -display_ruler 1 lib/Data/HexDump/Range.pm>
+The examples below show the output of the following command:
 
-=head3 Vertical
+  $>hdr -r 'magic cookie,12:padding, 32:header,5:data, 20:extra data,#:header,5:data,40:footer,4' -col -o ver -display_ruler 1 lib/Data/HexDump/Range.pm
+
+=head3 Vertical orientation
 
 In this orientation mode, each range displayed on a separate line.
 
@@ -162,7 +173,7 @@ In colors:
 
 =end html
 
-=head3 Horizontal
+=head3 Horizontal orientation
 
 In this mode, the data are packed together in the dump
 
@@ -179,7 +190,6 @@ In this mode, the data are packed together in the dump
 
 In colors:
 
-
 =begin html
 
 <pre style ="font-family: monospace; background-color: #000 ;">
@@ -209,7 +219,7 @@ Ranges are Array references containing two to four  elements:
 
 =item * name - a string
 
-=item * size - an integer
+=item * size - an integer or a format - a string
 
 =item * color - a string or undef
 
@@ -223,9 +233,18 @@ You can also pass the ranges as a string. The L<hdr> command line range dumper t
 
 Example:
 
-I<hdr --col -display_ruler -o ver lib/Data/HexDump/Range.pm -r 'header,12:name,10:magic,2:offset,4:BITMAP,4,bright_yellow:ff,x2b2:fx,b32:f0,b16:field,x8b8:field2, b17:footer,20'>
-       
-TODO: document string range format
+ $>hdr --col -display_ruler -o ver -r 'header,12:name,10:magic,2:offset,4:BITMAP,4,bright_yellow:ff,x2b2:fx,b32:f0,b16:field,x8b8:field2, b17:footer,20' my_binary
+
+=head3 Size field format
+
+The size field is used to defined if the range is a normal range, a comment, a bitfield or a skip range. The formats are a s follows:
+
+                  format                complete range example
+		  
+  normal range => integer               header, 4, bright_blue     
+  comment      => #                     data section start, # 
+  bitfield     => [xInteger]bInteger    bitfield, x8b4 
+  skip range   => xInteger              boring, x256,, comment
 
 =head3 Coloring
 
@@ -279,7 +298,7 @@ For simple data formats, your can put all the your range descriptions in a array
 	    ]
 	  ],
 	]
-	
+
 =head4 Comment ranges
 
 If the size of a range is the string '#', the whole range is considered a comment
@@ -301,17 +320,16 @@ If the size of a range is the string '#', the whole range is considered a commen
 
 Bitfields can be up to 32 bits long and can overlap each other. Bitfields are applied on the previously defined range.
 
-In the example below, bitfields I<ff, fx, f0> are extracted form the data defined by the I<MYDATA> range.
+In the example below, bitfields I<ff, fx, f0> are extracted form the data defined by the I<BITMAP> range.
 
                  .------------.                      .--------------.
-                 | data range |                      | data hexdump |
- .---.           '------------'                      '--------------'
- | b |                  |                                    |
- | i |     RANGE_NAME   |   OFFSET   CUMULATI HEX_DUMP       |                                 ASCII_DUMP     
- | t |     MYDATA  <----'   00000000 00000000 63 6f 6d 6d <--'                                 comm           
- | f |   ^ .ff              02 .. 03          -- -- -- 02 --10----------------------------     .bitfield: ---.
- | i |---> .fx              03 .. 19          -- 00 36 f6 ---00011011011110110------------     .bitfield: -.6?
- | e |   v .f0              07 .. 17          -- -- 05 bd -------10110111101--------------     .bitfield: --.?
+ .---.           | data range |                      | data hexdump |
+ | b |           '------------'                      '--------------'
+ | i |                  |                                    |
+ | t |     BITMAP  <----'   00000000 00000000 0a 70 61 63 <--'                                 .pac           
+ | f |   ^ .ff              02 .. 03          -- -- -- 00    ----------------------------00--  .bitfield: ---.
+ | i |---> .fx              00 .. 31          0a 70 61 63    00001010011100000110000101100011  .bitfield: .pac
+ | e |   v .f0              00 .. 15          -- -- 61 63    ----------------0110000101100011  .bitfield: --ac
  | l |                         ^                    ^                     ^                          ^
  | d |                         |                    |                     |                          |
  | s |             .----------------------.-------------------.----------------------.    .---------------------.
@@ -320,31 +338,65 @@ In the example below, bitfields I<ff, fx, f0> are extracted form the data define
 
 The the format definiton  is: an optional "x (for offset) + offset" + "b (for bits) + number of bits". Eg: I<x8b8> second byte in MYDATA.
 
-An example output containing normal data and bifields dumps.
+An example output containing normal data and bifields dumps using the comand below.
 
-command: I<hdr --col -display_ruler -o ver -r 'header,12:name,10:magic,2:offset,4:BITMAP,4,bright_yellow:ff,x2b2:fx,b32:f0,b16::footer,16' file_name
+  $>hdr  -r 'header,12:BITMAP,4,bright_yellow:ff,x2b2:fx,b32:f0,b16::footer,16' -o ver file_name
 
 =begin html
 
 <pre style ="font-family: monospace; background-color: #000 ;">
-
-<span style='color:#fff;'>RANGE_NAME       OFFSET   CUMULATI HEX_DUMP                                         ASCII_DUMP       </span> 
-<span style='color:#fff;'>                                   0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f   0123456789012345 </span> 
-<span style='color:#0f0;'>header          </span> <span style='color:#fff;'>00000000</span> <span style='color:#fff;'>00000000</span> <span style='color:#0f0;'>0a 70 61 63 6b 61 67 65 20 44 61 74             </span> <span style='color:#0f0;'>.package Dat    </span> 
-<span style='color:#ff0;'>name            </span> <span style='color:#fff;'>0000000c</span> <span style='color:#fff;'>00000000</span> <span style='color:#ff0;'>61 3a 3a 48 65 78 44 75 6d 70                   </span> <span style='color:#ff0;'>a::HexDump      </span> 
-<span style='color:#f0f;'>magic           </span> <span style='color:#fff;'>00000016</span> <span style='color:#fff;'>00000000</span> <span style='color:#f0f;'>3a 3a                                           </span> <span style='color:#f0f;'>::              </span> 
-<span style='color:#f00;'>offset          </span> <span style='color:#fff;'>00000018</span> <span style='color:#fff;'>00000000</span> <span style='color:#f00;'>52 61 6e 67                                     </span> <span style='color:#f00;'>Rang            </span> 
-<span style='color:#ff0;'>MYDATA          </span> <span style='color:#fff;'>0000001c</span> <span style='color:#fff;'>00000000</span> <span style='color:#ff0;'>65 20 3b 0a                                     </span> <span style='color:#ff0;'>e ;.            </span> 
-<span style='color:#fff;'>.ff             </span> <span style='color:#fff;'>02 .. 03</span> <span style='color:#fff;'>        </span> <span style='color:#fff;'>-- -- -- 02 --10----------------------------    </span> <span style='color:#fff;'>.bitfield: ---. </span> 
-<span style='color:#0f0;'>.fx             </span> <span style='color:#0f0;'>00 .. 31</span> <span style='color:#0f0;'>        </span> <span style='color:#0f0;'>65 20 3b 0a 01100101001000000011101100001010    </span> <span style='color:#0f0;'>.bitfield: e ;. </span> 
-<span style='color:#ff0;'>.f0             </span> <span style='color:#ff0;'>00 .. 15</span> <span style='color:#ff0;'>        </span> <span style='color:#ff0;'>-- -- 65 20 0110010100100000----------------    </span> <span style='color:#ff0;'>.bitfield: --e  </span> 
-<span style='color:#f0f;'>footer          </span> <span style='color:#fff;'>00000020</span> <span style='color:#fff;'>00000000</span> <span style='color:#f0f;'>0a 75 73 65 20 73 74 72 69 63 74 3b 0a 75 73 65 </span> <span style='color:#f0f;'>.use strict;.use</span> 
-
+<span style = 'color:#fff;  color:#0f0; '>header          </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0f0; '>0a 70 61 63 6b 61 67 65 20 44 61 74             </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0f0; '>.package Dat    </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#ff0; '>BITMAP          </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>0000000c</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>61 3a 3a 48                                     </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>a::H            </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#ff0; '>.ff             </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>02 .. 03</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>        </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>-- -- -- 02    ----------------------------10-- </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>.bitfield: ---. </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#0ff; '>.fx             </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>00 .. 31</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>        </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>61 3a 3a 48    01100001001110100011101001001000 </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>.bitfield: a::H </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#f00; '>.f0             </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#f00; '>00 .. 15</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#f00; '>        </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#f00; '>-- -- 3a 48    ----------------0011101001001000 </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#f00; '>.bitfield: --:H </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#fff; '>footer          </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000010</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#fff; '>65 78 44 75 6d 70 3a 3a 52 61 6e 67 65 20 3b 0a </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#fff; '>exDump::Range ;.</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span>
 </pre>
 
 =end html
 
-B<NOTE!> This is under heavy developemnt. Complete error handling and indianess support are under way.
+By default bitfields are not displayed  in horizontal mode.
+
+=head3 Skip ranges
+
+If the size format is 'x' + number, that number of bytes is skipped from the data. B<Data::HexDump::Range>
+will display the skip range in the dump but not the data.
+
+In the command below, the range 'skip' removes 32 bytes from the display. '>>' is prepended to the range name.
+
+Command: I<hdr -r 'magic cookie, 5   :other,37  :bf,b8   :skip,x32,, I skipped :more, 20'  -rul -col -o ver>
+
+ RANGE_NAME       OFFSET   CUMULATI HEX_DUMP                                         ASCII_DUMP
+                                    0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f   0123456789012345
+ magic cookie     00000000 00000000 63 6f 6d 6d 69                                   commi
+ other            00000005 00000000 74 20 31 39 39 61 34 62 31 32 37 62 32 39 66 39  t 199a4b127b29f9
+ other            00000015 00000010 31 64 32 65 36 33 66 39 35 66 38 63 34 30 62 64  1d2e63f95f8c40bd
+ other            00000025 00000020 65 31 39 62 61                                   e19ba
+ .bf              00 .. 07          -- -- -- 61    ------------------------01100001  .bitfield: ---a
+ >>skip           0000002a 00000049 00 00 00 20 bytes skipped
+ more             0000004a 00000000 69 6d 20 6b 68 65 6d 69 72 20 3c 6e 6b 68 40 63  im khemir <nkh@c
+ more             0000005a 00000010 70 61 6e 2e                                      pan.
+
+in color:
+
+=begin html
+
+<pre style ="font-family: monospace; background-color: #000 ;">
+<span style = 'color:#fff;  color:#fff; '>RANGE_NAME       OFFSET   CUMULATI HEX_DUMP                                         ASCII_DUMP       </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#fff; '>                                   0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f   0123456789012345 </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#0f0; '>magic cookie    </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0f0; '>63 6f 6d 6d 69                                  </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0f0; '>commi           </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#ff0; '>other           </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000005</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>74 20 31 39 39 61 34 62 31 32 37 62 32 39 66 39 </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>t 199a4b127b29f9</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#ff0; '>other           </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000015</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000010</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>31 64 32 65 36 33 66 39 35 66 38 63 34 30 62 64 </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>1d2e63f95f8c40bd</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#ff0; '>other           </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000025</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000020</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>65 31 39 62 61                                  </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#ff0; '>e19ba           </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#0ff; '>.bf             </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>00 .. 07</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>        </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>-- -- -- 61    ------------------------01100001 </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#0ff; '>.bitfield: ---a </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#f00; '>&gt;&gt;skip          </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>0000002a</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000049</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#f00; '>00 00 00 20 bytes skipped                       </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#f00; '>                </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#fff; '>more            </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>0000004a</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000000</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#fff; '>69 6d 20 6b 68 65 6d 69 72 20 3c 6e 6b 68 40 63 </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#fff; '>im khemir &lt;nkh@c</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span><span style = 'color:#fff;  color:#fff; '>more            </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>0000005a</span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>00000010</span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#fff; '>70 61 6e 2e                                     </span><span style = 'color:#fff; '> </span><span style = 'color:#fff;  color:#fff; '>pan.            </span><span style = 'color:#fff; '> </span><span style = 'color:#fff; '>
+</span>
+</pre>
+
+=end html
 
 =head3 Dynamic range definition
 
@@ -367,7 +419,7 @@ a subroutine definition.
   }
   
   $hdr->dump([\&cloth_size, 1, 'yellow'], $data) ;
-  
+
 =head4 'size' sub ref
 
   sub cloth_size
@@ -377,7 +429,7 @@ a subroutine definition.
   }
   
   $hdr->dump(['data', \&get_size, 'yellow'], $data) ;
-  
+
 =head4 'color' sub ref
 
   my $flip_flop = 1 ;
@@ -395,7 +447,7 @@ a subroutine definition.
 
 =head3  User defined range generator
 
-A subroutine reference can be passed as a range definition. The cubroutine will be called repetitively
+A subroutine reference can be passed as a range definition. The subroutine will be called repetitively
 till the data is exhausted or the subroutine returns I<undef>.
 
   sub my_parser 
@@ -444,15 +496,7 @@ OR
 
 =head1 EXAMPLES
 
-See L<hdr_user_manual>
-
-=head1 OTHER IDEAS
-
-- allow pack format as range size
-	pack in array context returns the amount of fields processed
-	fixed format can be found with a length of unpack
-
-- hook with Convert::Binary::C to automatically create ranges
+See I<hdr_examples.pod> in the distribution.
 
 =head1 SUBROUTINES/METHODS
 
@@ -566,6 +610,8 @@ in base 10. Default is 'hex'.
 
 =item * DISPLAY_CUMULATIVE_OFFSET - Boolean - If set, the cumulative offset column is displayed in 'vertical' rendering mode. Default is I<true>
 
+=item * OFFSET_START - Integer - value added to the offset. 
+
 =item * DISPLAY_ZERO_SIZE_RANGE - Boolean - if set, ranges that do not consume data are displayed. default is I<true> 
 
 =item * DISPLAY_ZERO_SIZE_RANGE_WARNING - Boolean - if set, a warning is emitted if ranges that do not consume data. Default is I<true> 
@@ -582,6 +628,8 @@ in base 10. Default is 'hex'.
 
 =item * DISPLAY_BITFIELDS - Boolean - if set the bitfields are displayed
 
+=item * BIT_ZERO_ON_LEFT - Boolean - if set the bit of index 0 is on left growing to the right. Default I<false>
+
 =item * COLOR_NAMES - A hash reference
 
   {
@@ -712,7 +760,7 @@ return $self->format($split_data) ;
 
 #-------------------------------------------------------------------------------
 
-sub dump
+sub dump ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
 
 =head2 dump($range_description, $data, $offset, $size)
@@ -731,7 +779,9 @@ my ($self, $range_description, $data, $offset, $size) = @_ ;
 
 return unless defined wantarray ;
 
-my ($gathered_data, $used_data) = $self->_gather(undef, $range_description, $data, $offset, $size) ;
+local $self->{GATHERED} = [] ;
+
+my ($gathered_data, $used_data) = $self->_gather($self->{GATHERED}, $range_description, $data, $offset, $size) ;
 
 my $split_data = $self->split($gathered_data) ;
 
@@ -765,11 +815,11 @@ I<Exceptions> - dies if the range description is invalid
 
 =cut
 
-my ($self) = shift ;
+my ($self,$data, $offset, $size) = @_ ;
 
 return unless defined wantarray ;
 
-my ($gathered_data, $used_data) = $self->_gather(undef, @_) ;
+my ($gathered_data, $used_data) = $self->_gather(undef, $data, $offset, $size) ;
 
 my $dump =$self->format($self->split($gathered_data)) ;
 
@@ -778,7 +828,7 @@ return  $dump, $used_data ;
 
 #-------------------------------------------------------------------------------
 
-sub reset
+sub reset ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 {
 
 =head2 reset()
@@ -814,9 +864,9 @@ None so far.
 	CPAN ID: NKH
 	mailto: nadim@cpan.org
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 Nadim Khemir.
+Copyright Nadim Khemir 2010.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of either:
